==> huaweicloudsdkrocketmq-3.1.52-py2.py3-none-any.whl: huaweicloudsdkrocketmq/v2/model/deadletter_resend_resp_resend_results.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeadletterResendRespResendResults:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'msg_id': 'str',
        'error_code': 'str',
        'error_message': 'str'
    }

    attribute_map = {
        'msg_id': 'msg_id',
        'error_code': 'error_code',
        'error_message': 'error_message'
    }

    def __init__(self, msg_id=None, error_code=None, error_message=None):
        """DeadletterResendRespResendResults

        The model defined in huaweicloud sdk

        :param msg_id: 消息ID。
        :type msg_id: str
        :param error_code: 错误码。
        :type error_code: str
        :param error_message: 错误信息。
        :type error_message: str
        """
        
        

        self._msg_id = None
        self._error_code = None
        self._error_message = None
        self.discriminator = None

        if msg_id is not None:
            self.msg_id = msg_id
        if error_code is not None:
            self.error_code = error_code
        if error_message is not None:
            self.error_message = error_message

    @property
    def msg_id(self):
        """Gets the msg_id of this DeadletterResendRespResendResults.

        消息ID。

        :return: The msg_id of this DeadletterResendRespResendResults.
        :rtype: str
        """
        return self._msg_id

    @msg_id.setter
    def msg_id(self, msg_id):
        """Sets the msg_id of this DeadletterResendRespResendResults.

        消息ID。

        :param msg_id: The msg_id of this DeadletterResendRespResendResults.
        :type msg_id: str
        """
        self._msg_id = msg_id

    @property
    def error_code(self):
        """Gets the error_code of this DeadletterResendRespResendResults.

        错误码。

        :return: The error_code of this DeadletterResendRespResendResults.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this DeadletterResendRespResendResults.

        错误码。

        :param error_code: The error_code of this DeadletterResendRespResendResults.
        :type error_code: str
        """
        self._error_code = error_code

    @property
    def error_message(self):
        """Gets the error_message of this DeadletterResendRespResendResults.

        错误信息。

        :return: The error_message of this DeadletterResendRespResendResults.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this DeadletterResendRespResendResults.

        错误信息。

        :param error_message: The error_message of this DeadletterResendRespResendResults.
        :type error_message: str
        """
        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeadletterResendRespResendResults):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrocketmq-3.1.155-py2.py3-none-any.whl: huaweicloudsdkrocketmq/v2/model/deadletter_resend_resp_resend_results.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeadletterResendRespResendResults:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'msg_id': 'str',
        'error_code': 'str',
        'error_message': 'str'
    }

    attribute_map = {
        'msg_id': 'msg_id',
        'error_code': 'error_code',
        'error_message': 'error_message'
    }

    def __init__(self, msg_id=None, error_code=None, error_message=None):
        r"""DeadletterResendRespResendResults

        The model defined in huaweicloud sdk

        :param msg_id: 消息ID。
        :type msg_id: str
        :param error_code: 错误码。
        :type error_code: str
        :param error_message: 错误信息。
        :type error_message: str
        """
        
        

        self._msg_id = None
        self._error_code = None
        self._error_message = None
        self.discriminator = None

        if msg_id is not None:
            self.msg_id = msg_id
        if error_code is not None:
            self.error_code = error_code
        if error_message is not None:
            self.error_message = error_message

    @property
    def msg_id(self):
        r"""Gets the msg_id of this DeadletterResendRespResendResults.

        消息ID。

        :return: The msg_id of this DeadletterResendRespResendResults.
        :rtype: str
        """
        return self._msg_id

    @msg_id.setter
    def msg_id(self, msg_id):
        r"""Sets the msg_id of this DeadletterResendRespResendResults.

        消息ID。

        :param msg_id: The msg_id of this DeadletterResendRespResendResults.
        :type msg_id: str
        """
        self._msg_id = msg_id

    @property
    def error_code(self):
        r"""Gets the error_code of this DeadletterResendRespResendResults.

        错误码。

        :return: The error_code of this DeadletterResendRespResendResults.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        r"""Sets the error_code of this DeadletterResendRespResendResults.

        错误码。

        :param error_code: The error_code of this DeadletterResendRespResendResults.
        :type error_code: str
        """
        self._error_code = error_code

    @property
    def error_message(self):
        r"""Gets the error_message of this DeadletterResendRespResendResults.

        错误信息。

        :return: The error_message of this DeadletterResendRespResendResults.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        r"""Sets the error_message of this DeadletterResendRespResendResults.

        错误信息。

        :param error_message: The error_message of this DeadletterResendRespResendResults.
        :type error_message: str
        """
        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeadletterResendRespResendResults):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
